Crate mprobe_vis

Crate mprobe_vis 

mprobe’s visualization library.

WARNING: This library is the mprobe’s visualization internal library and there are no plans to stabilize it. The API may break at any time without notice.

Modules

error
Defines the Error and Result types that this crate uses.
layout
Defines the structure and the layout of the data used for visualizing diagnostic metrics.