Module error

Module error 

Defines the Error and Result types that this crate uses.

Enums

VisError
The error type for generating a visualization report of diagnostic metrics.

Type Aliases

Result
The result type that uses VisError as the error type.